@@ -26,7 +26,11 @@ def _rendered_image_to_dir(
     """
     clearplot_code = dedent(clearplot_code)
 
-    savefig_code = f'plt.savefig("{save_img_dir}")'
+    savefig_code = f"""
+    plt.tight_layout()
+    plt.savefig("{save_img_dir}")
+    """
+    savefig_code = dedent(savefig_code)
     closefig_code = "plt.close()"
 
     # create namespace if not passed
